{% extends 'base.html' %}
{% load i18n %}

{% block headline %}{% block title %}{% trans 'Watch on repository' %}{% endblock %}{% endblock %}

{% block content %}
    <p>{% trans 'Only URLs of SVN repositories are support now.' %}</p>

    <form action="" method="post">
        {% if user.is_anonymous %}
            <p>
            {{ form.url.errors }}
            <label for="id_url">{% trans 'URL' %}:</label>
            {{ form.url }}
            </p>
        {% else %}
            {{form.as_p}}
        {% endif %}
        <input type="submit" value="{% trans 'Add' %}"/>
    </form>
    {% if user.is_anonymous %}
        <p>{% trans 'To be able to add nonpublic repositories you must sign-in.' %}</p>
    {% endif %}
{% endblock %}

