<html>
    <head>
        <style>{% block style %}{% endblock %}</style>
        <title>{% block title %}{% endblock %}</title>
        {% block head %}{% endblock %}
    </head>
    <body>
        {% block full_headline %}<h1>{% block headline %}{% endblock %}{% endblock %}
        {% block content %}{% endblock %}
    </body>
</html>

